########################################################################
# Configuration	:	latex.mk
#-----------------------------------------------------------------------
# Description	:	Macro definitions to process LaTeX documents using
#					BibTeX
#-----------------------------------------------------------------------
# Note			:	GNU Make required
########################################################################

#LATEX = latex209
LATEX = latex
BIBTEX = bibtex
DVIPS = dvips
#DVIPSFLAGS = -d 4
XDVI = xdvi
XDVIFLAGS =

INF:= $(shell basename `pwd`)
# use the following if using standard make(1)
#INF:sh=basename `pwd`

STYFILES = $(INF)

DVIFILES = $(TEXFILES:%.tex=%.dvi)
PSFILES = $(DVIFILES:%.dvi=%.ps)
ESCFILES = $(PSFILES:%.ps=%.esc)
BIBFILES = $(HOME)/lib/informatique.bib

#-----------------------------------------------------------------------
# PostScript printer
#-----------------------------------------------------------------------
#PRINTER = glw
#PRINTER = hpp
PRINTER = ps

#-----------------------------------------------------------------------
# Create dvi file from tex file
#-----------------------------------------------------------------------
%.dvi: %.tex
	$(LATEX) $<
	@if (egrep '(No file .*\.bbl|No file .*\.toc|Citation)' $*.log >/dev/null); then \
		($(BIBTEX) $*; $(LATEX) $*.tex);\
	fi
	@if (grep 'Rerun to' $*.log > /dev/null); then \
		$(LATEX) $*.tex; \
	fi

#-----------------------------------------------------------------------
# Create PostScript file from dvi file
#-----------------------------------------------------------------------
%.ps: %.dvi
	$(DVIPS) $(DVIPSFLAGS) -o $@ $<

#-----------------------------------------------------------------------
# Create PostScript file of a gnuplot
#-----------------------------------------------------------------------
%.ps: %.gnu
	gnuplot $<

#-----------------------------------------------------------------------
# Create ESC/P2 file from PostScript file
#-----------------------------------------------------------------------
%.esc: %.ps
	gs -q -dSAFER -dNOPAUSE -sDEVICE=escp2 -r360x180 -sOutputFile=- - < $< > $@

#-----------------------------------------------------------------------
# Create a latex picture file from an xfig file
#-----------------------------------------------------------------------
%.pic: %.fig
	fig2dev -L latex $< $@

#-----------------------------------------------------------------------
# Create a PostScript file from an xfig file
#-----------------------------------------------------------------------
%.ps: %.fig
	fig2dev -L ps $< $@

########################################################################
all: $(DVIFILES)

view: $(DVIFILES)
	$(XDVI) $(XDVIFLAGS) $< &

ps: $(PSFILES)

esc: $(ESCFILES)

print: $(PSFILES)
	lpr -P$(PRINTER) $<

#.PHONY: clean
clean:
	$(RM) *.dvi *.aux *.ps *.bbl *.blg *.log *.lof *.lot *.toc *.ent
