%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Class			:	$Id: muthesis.cls,v 1.8 1996/10/24 12:26:02 bernard Exp $
%-----------------------------------------------------------------------
% Description	:	Customization of the standard LaTeX Report document
%					class for master's thesis at McGill University.
%-----------------------------------------------------------------------
% Author		:	Bernard Desruisseaux (bernard@cs.mcgill.ca)
%-----------------------------------------------------------------------
% Copyright		:	(c) 1996 by Bernard Desruisseaux.
%					All rights reserved.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{muthesis}[1996/06/14 v1.0 McGill Thesis Class]

%-----------------------------------------------------------------------
% Initial code.
%-----------------------------------------------------------------------
\RequirePackage{calc}
\RequirePackage{ifthen}
\newboolean{draft}

%-----------------------------------------------------------------------
% Declaration of options.  Unknown ones are passed to the report class.
%-----------------------------------------------------------------------
\DeclareOption{draft}{\sloppy
	 \setboolean{draft}{true}\PassOptionsToClass{draft}{report}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
 
%-----------------------------------------------------------------------
% Execute the options.
%-----------------------------------------------------------------------
\ProcessOptions
 
%-----------------------------------------------------------------------
% Class & Package loading.
%-----------------------------------------------------------------------
\LoadClass{report}
\RequirePackage[hang]{caption2}
\RequirePackage{metamorfont}
\RequirePackage{setspace} % patched to work with color package.
\RequirePackage{fancyhdr}

%-----------------------------------------------------------------------
% Class Font Selection.
%-----------------------------------------------------------------------
\def\@halftitlefont{\normalfont\huge\sffamily\bfseries}
\def\@titlefont{\normalfont\Huge\sffamily\bfseries}
\def\@authorfont{\fmfxparams{
					/Craziness 65
					/JumpyFont true
					/JumpyFactor 35
					/RestoreHeight false
					/UseConstraints false
				}\huge\bfseries\fmffamily}
\def\@affiliationfont{\normalfont}
\def\@datefont{\normalfont}
\def\@submissionfont{\normalfont}
\def\@dedicationfont{\fmfrparams{
					/Craziness 100
					/JumpyFont true
					/JumpyFactor 40
				}\Large\fmffamily}
\def\@headingfont{\normalfont\normalsize\sffamily\bfseries}
\def\@chapternumfont{\normalfont\Huge\sffamily\bfseries}
\def\@chapterfont{\normalfont\LARGE\sffamily\bfseries}
\def\@sectionfont{\normalfont\large\sffamily\bfseries}
\def\@subsectionfont{\normalfont\normalsize\sffamily\bfseries}
\def\@subsubsectionfont{\normalfont\normalsize\sffamily}
\def\@paragraphfont{\normalfont\normalsize\sffamily}
\def\@subparagraphfont{\normalfont\normalsize\sffamily}
\def\@captionfont{\normalfont\normalsize\sffamily}
\def\@captionlabelfont{\@captionfont}

%-----------------------------------------------------------------------
% Caption2 package parameters.
%-----------------------------------------------------------------------
\renewcommand{\captionfont}{\@captionfont}
\renewcommand{\captionlabelfont}{\@captionlabelfont}
\renewcommand{\captionlabeldelim}{.\ } % instead of colon (:)

%-----------------------------------------------------------------------
% verbatim.sty  (might want to add \fontencoding{T1}\selectfont ?)
%-----------------------------------------------------------------------
%\def\verbatim@font{\normalfont\ttfamily
%                   \let\do\do@noligs
%                   \verbatim@nolig@list}

%-----------------------------------------------------------------------
% Sectionning commands settings
%-----------------------------------------------------------------------
\setcounter{tocdepth}{1}	% only chapters and sections in .toc
\setcounter{secnumdepth}{1}	% only chapters and sections are numbered

%----
%---- \l@chapter{text}{page}
%----
\newcommand*\l@chapter@nodot[2]{%
	\ifnum \c@tocdepth >\m@ne
		\addpenalty{-\@highpenalty}%
		\vskip 1.0em \@plus\p@
		\setlength\@tempdima{1.5em}%
		\begingroup
			\parindent \z@
			\leavevmode \bfseries
			\advance\leftskip\@tempdima
			\hskip -\leftskip
			#1\quad#2\par
			\penalty\@highpenalty
		\endgroup
	\fi}

%----
%---- \@tocline{level}{indent}{numwidth}{text}{page}
%----
\def\@tocline#1#2#3#4#5{%
	\ifnum #1>\c@tocdepth \else
	\vskip \z@ \@plus.2\p@
	{\leftskip #2\relax\parindent #2\relax\@afterindenttrue
	\interlinepenalty\@M
	\leavevmode
	\@tempdima #3\relax
	\advance\leftskip \@tempdima
	\null\hskip -\leftskip
    #4\quad#5\par}\fi}

%\newcommand*\l@section{\@dottedtocline{1}{1.5em}{2.3em}}

%----
%---- Make table of contents without dots
%----
\let\l@chapter\l@chapter@nodot
\let\@dottedtocline\@tocline

%-----------------------------------------------------------------------
% Page Layout. {LC 84}
%-----------------------------------------------------------------------
\normalsize	% set normal \baselineskip
\setlength{\topmargin}{0pt}
\setlength{\headsep}{25pt}
\setlength{\headheight}{12pt}
\ifthenelse{\@ptsize = 1}{\addtolength{\headheight}{1.59999pt}}{}
\ifthenelse{\@ptsize = 2}{\addtolength{\headheight}{2.49998pt}}{}
\setlength{\footskip}{\headheight+\headsep}
\setlength{\textheight}{\paperheight-2in-\voffset-\topmargin
						-\headheight-\headsep-\footskip-\topskip}
\newcounter{tempc}\setcounter{tempc}{\textheight}
\newcounter{tempcc}\setcounter{tempcc}{\baselineskip}
\setcounter{tempc}{\value{tempc}/\value{tempcc}}
\setlength{\textheight}{\baselineskip*\value{tempc}+\topskip}
\setlength{\textwidth}{5.0in}
\setlength{\oddsidemargin}{1.5in}
\setlength{\evensidemargin}{\oddsidemargin}
\setlength{\marginparsep}{7pt}
\setlength{\marginparwidth}{65pt}
\reversemarginpar

%-----------------------------------------------------------------------
% Page style. (using Fancy Header) {LC 96}
%-----------------------------------------------------------------------
\pagestyle{fancy}
\setlength{\headwidth}{\textwidth+\marginparsep+\marginparwidth}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0pt}
\renewcommand{\chaptermark}[1]{\markboth{\thechapter.\ #1}{}}
\renewcommand{\sectionmark}[1]{}
\fancyhf{}
\fancyhead[r]{\@headingfont\thepage}
\fancyhead[l]{\@headingfont\nouppercase{\leftmark}}
\fancypagestyle{plain}{\fancyhead{}\fancyfoot[r]{\@headingfont\thepage}}
\ifthenelse{\boolean{draft}}
	{\fancyfoot[l]{\@headingfont Draft:~\RCSRevision}}{}

%-----------------------------------------------------------------------
% New environments.
%-----------------------------------------------------------------------
\newenvironment{dedication}
	{\clearpage\thispagestyle{empty}\vspace*{120pt}
	 \begin{flushright}\obeylines\@dedicationfont}
	{\end{flushright}}

\newenvironment{longlines}{\begin{list}{}{%
	\setlength{\topsep}{0pt}%
	\setlength{\leftmargin}{0pt}%
	\setlength{\rightmargin}{0pt}%
	\setlength{\listparindent}{\parindent}%
	\setlength{\itemindent}{\parindent}%
	\setlength{\parsep}{0pt plus 1pt}%
	\addtolength{\leftmargin}{-\marginparsep-\marginparwidth}%
	}\item}%
	{\end{list}}

%\newlength{\verbatimewidth}
%\setlength{\verbatimewidth}{\headwidth - \parindent}
%\newenvironment{verbatimwide}%
%	{\singlespacing\VerbatimEnvironment\begin{longlines}
%	 \begin{minipage}{\verbatimewidth}\begin{Verbatim}}%
%	{\end{Verbatim}\end{minipage}\end{longlines}}

%-----------------------------------------------------------------------
% Customization of sectioning commands previously defined in report.cls
%-----------------------------------------------------------------------
%----
%---- Make \chapter heading
%----
\def\@makechapterhead#1{{\parindent 0pt\raggedright\interlinepenalty\@M
	\hbox{\ifnum\c@secnumdepth>\m@ne
		\llap{\@chapternumfont\thechapter\quad}\fi
		\@chapterfont#1}\par\nobreak
	\vskip-\parskip
	\begin{longlines}\rule{\linewidth}{0.4pt}\end{longlines}
	\vskip 1in}}

%----
%---- Make \chapter* (starred form) heading
%----
\def\@makeschapterhead#1{{\parindent 0pt\raggedright\interlinepenalty\@M%
	\@chapterfont#1\par\nobreak
	\vskip-\parskip
	\begin{longlines}\rule{\linewidth}{0.4pt}\end{longlines}
	\vskip 1in}}

%----
%---- Section counter format
%----
\renewcommand{\@seccntformat}[1]{\llap{\csname the#1\endcsname\quad}}

%----
%---- Sectionning commands format
%----
\renewcommand\section{\@startsection {section}{1}{\z@}%
						{-3.5ex \@plus -1ex \@minus -.2ex}%
						{2.3ex \@plus.2ex}%
						{\@sectionfont}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
						{-3.25ex\@plus -1ex \@minus -.2ex}%
						{1.5ex \@plus .2ex}%
						{\@subsectionfont}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
						{-3.25ex\@plus -1ex \@minus -.2ex}%
						{1.5ex \@plus .2ex}%
						{\@subsubsectionfont}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
						{3.25ex \@plus1ex \@minus.2ex}%
						{-1em}%
						{\@paragraphfont}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
						{3.25ex \@plus1ex \@minus .2ex}%
						{-1em}%
						{\@subparagraphfont}}

%-----------------------------------------------------------------------
% Redefine this command if you want the ``true'' copyright symbol.
%-----------------------------------------------------------------------
\newcommand{\Copyright}{\copyright}

%-----------------------------------------------------------------------
% New commands.
%-----------------------------------------------------------------------
\newcommand{\nohypens}{\hyphenpenalty=10000\exhyphenpenalty=10000\relax}
\newcommand{\french}{\language1}

\newcommand{\makehalftitlepage}{%
	\clearpage
	\thispagestyle{empty}
	\vspace*{50pt}
	\begin{center}
		\@halftitlefont\@title
	\end{center}}

\def\affiliation#1{\gdef\@affiliation{#1}}
\def\@affiliation{School of Computer Science\\McGill University, Montreal}
\def\submission#1{\gdef\@submission{#1}}
\def\@submission{A thesis submitted to the Faculty of Graduate\\
				 Studies and Research in partial fulfilment of the\\
                 requirements of the degree of Master of Science}

\newcommand{\maketitlepage}{%
	\clearpage
	\thispagestyle{empty}
	\vspace*{50pt}
	\begin{center}
		{\@titlefont\@title}
		\obeylines
		\par\vspace*{\stretch{2}}
		{\@authorfont\@author}
		\par\vspace{48pt}
		{\@affiliationfont\@affiliation}
		\par\vspace{24pt}
		{\@datefont\@date}
		\par\vspace*{\stretch{1}}
		{\@submissionfont\@submission}
		\par\vspace{18pt}
		Copyright \Copyright\ 1996 by \@author
	\end{center}}

%----
%---- The \numberline{} produces an indented entry instead of flushleft
%----
\newcommand{\prelimchapter}[1]{%
	\singlespacing\chapter*{#1\markboth{#1}{}}\doublespacing%
	\addcontentsline{toc}{chapter}{\numberline{}#1}}

%-----------------------------------------------------------------------
% Input User's Configuration.
%-----------------------------------------------------------------------
\InputIfFileExists{muthesis.cfg}{}{}

\endinput
%% 
%% End of file `muthesis.cls'.
